summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGiWoong Kim <giwoong.kim@samsung.com>2013-11-22 11:06:37 +0900
committerGiWoong Kim <giwoong.kim@samsung.com>2013-11-22 11:06:37 +0900
commita8e0f2e643f4622a56208ffb405739aa7b9f4831 (patch)
treee7b1b28eccbaeae38f37d8bf138ca2078b707040
parentf963e4053d6779793fa18c533446f0822f6f0f5f (diff)
downloadqemu-a8e0f2e643f4622a56208ffb405739aa7b9f4831.tar.gz
qemu-a8e0f2e643f4622a56208ffb405739aa7b9f4831.tar.bz2
qemu-a8e0f2e643f4622a56208ffb405739aa7b9f4831.zip
display: modified some variable & function names
In Qemu, to avoid a confusing about screen size, I changed some variable names and function names. (set_emul_lcd_size -> set_emul_resolution) Change-Id: I567291504aab16f04255d16351fb18e40223e1b6 Signed-off-by: GiWoong Kim <giwoong.kim@samsung.com>
-rw-r--r--tizen/src/emul_state.c20
-rw-r--r--tizen/src/emul_state.h12
-rw-r--r--tizen/src/emulator.c2
-rw-r--r--tizen/src/maru_finger.c4
-rw-r--r--tizen/src/maru_sdl.c14
-rw-r--r--tizen/src/maru_shm.c10
-rw-r--r--tizen/src/skin/maruskin_operation.c2
7 files changed, 32 insertions, 32 deletions
diff --git a/tizen/src/emul_state.h b/tizen/src/emul_state.h
index 993f317a99..b58ee6dc71 100644
--- a/tizen/src/emul_state.h
+++ b/tizen/src/emul_state.h
@@ -1,5 +1,5 @@
/*
- * Emulator
+ * Emulator State Information
*
* Copyright (C) 2011 - 2013 Samsung Electronics Co., Ltd. All rights reserved.
*
@@ -82,8 +82,8 @@ enum {
typedef struct EmulatorConfigInfo {
int skin_enable;
- int lcd_size_w;
- int lcd_size_h;
+ int resolution_w;
+ int resolution_h;
int sdl_bpp;
bool input_mouse_enable;
bool input_touch_enable;
@@ -107,7 +107,7 @@ typedef struct EmulatorConfigState {
/* setter */
void set_emul_skin_enable(int enable);
-void set_emul_lcd_size(int width, int height);
+void set_emul_resolution(int width, int height);
void set_emul_win_scale(double scale);
void set_emul_sdl_bpp(int bpp);
void set_emul_input_mouse_enable(bool on);
@@ -123,8 +123,8 @@ void set_emul_vm_name(char *vm_name);
/* getter */
int get_emul_skin_enable(void);
-int get_emul_lcd_width(void);
-int get_emul_lcd_height(void);
+int get_emul_resolution_width(void);
+int get_emul_resolution_height(void);
double get_emul_win_scale(void);
int get_emul_sdl_bpp(void);
bool is_emul_input_mouse_enable(void);
diff --git a/tizen/src/emulator.c b/tizen/src/emulator.c
index 7850cd9925..08f0d3977e 100644
--- a/tizen/src/emulator.c
+++ b/tizen/src/emulator.c
@@ -293,7 +293,7 @@ static void extract_skin_info(int skin_argc, char **skin_argv)
}
if (w != 0 && h != 0) {
- set_emul_lcd_size(w, h);
+ set_emul_resolution(w, h);
break;
}
}
diff --git a/tizen/src/maru_finger.c b/tizen/src/maru_finger.c
index 669e3fbd47..c6b61c47a4 100644
--- a/tizen/src/maru_finger.c
+++ b/tizen/src/maru_finger.c
@@ -387,8 +387,8 @@ void maru_finger_processing_2(
int distance_x = x - finger->x;
int distance_y = y - finger->y;
- int current_screen_w = get_emul_lcd_width();
- int current_screen_h = get_emul_lcd_height();
+ int current_screen_w = get_emul_resolution_width();
+ int current_screen_h = get_emul_resolution_height();
int temp_finger_x, temp_finger_y;
int i = 0;
diff --git a/tizen/src/maru_sdl.c b/tizen/src/maru_sdl.c
index 28e4f85539..571ed36c6a 100644
--- a/tizen/src/maru_sdl.c
+++ b/tizen/src/maru_sdl.c
@@ -249,8 +249,8 @@ static void qemu_ds_sdl_switch(DisplayChangeListener *dcl,
}
/* create surface_qemu */
- if (console_width == get_emul_lcd_width() &&
- console_height == get_emul_lcd_height()) {
+ if (console_width == get_emul_resolution_width() &&
+ console_height == get_emul_resolution_height()) {
INFO("create SDL screen : (%d, %d)\n",
console_width, console_height);
@@ -265,7 +265,7 @@ static void qemu_ds_sdl_switch(DisplayChangeListener *dcl,
dpy_surface->pf.amask);
} else {
INFO("create blank screen : (%d, %d)\n",
- get_emul_lcd_width(), get_emul_lcd_height());
+ get_emul_resolution_width(), get_emul_resolution_height());
surface_qemu = SDL_CreateRGBSurface(
SDL_SWSURFACE,
@@ -686,8 +686,8 @@ static void maru_sdl_resize_bh(void *opaque)
#endif
/* get current setting information and calculate screen size */
- display_width = get_emul_lcd_width();
- display_height = get_emul_lcd_height();
+ display_width = get_emul_resolution_width();
+ display_height = get_emul_resolution_height();
current_scale_factor = get_emul_win_scale();
short rotaton_type = get_emul_rotation();
@@ -750,7 +750,7 @@ static void maru_sdl_resize_bh(void *opaque)
/* rearrange multi-touch finger points */
if (get_emul_multi_touch_state()->multitouch_enable == 1 ||
get_emul_multi_touch_state()->multitouch_enable == 2) {
- rearrange_finger_points(get_emul_lcd_width(), get_emul_lcd_height(),
+ rearrange_finger_points(get_emul_resolution_width(), get_emul_resolution_height(),
current_scale_factor, rotaton_type);
}
@@ -812,7 +812,7 @@ void maruskin_sdl_init(uint64 swt_handle,
INFO("register SDL environment variable. "
"(SDL_WINDOWID = %s)\n", SDL_windowhack);
- set_emul_lcd_size(display_width, display_height);
+ set_emul_resolution(display_width, display_height);
set_emul_sdl_bpp(SDL_BPP);
init_multi_touch_state();
diff --git a/tizen/src/maru_shm.c b/tizen/src/maru_shm.c
index 261032c0af..5efb83cd66 100644
--- a/tizen/src/maru_shm.c
+++ b/tizen/src/maru_shm.c
@@ -110,7 +110,7 @@ static void qemu_ds_shm_update(DisplayChangeListener *dcl,
surface_height(dpy_surface));
} else {
int shm_size =
- get_emul_lcd_width() * get_emul_lcd_height() * 4;
+ get_emul_resolution_width() * get_emul_resolution_height() * 4;
memset(shared_memory, 0x00, (size_t)shm_size);
}
@@ -152,8 +152,8 @@ static void qemu_ds_shm_switch(DisplayChangeListener *dcl,
INFO("qemu_ds_shm_switch : (%d, %d)\n",
console_width, console_height);
- if (console_width == get_emul_lcd_width() &&
- console_height == get_emul_lcd_height()) {
+ if (console_width == get_emul_resolution_width() &&
+ console_height == get_emul_resolution_height()) {
is_fit_console_size = true;
}
}
@@ -221,7 +221,7 @@ void maruskin_shm_init(uint64 swt_handle,
INFO("maru shm init\n");
- set_emul_lcd_size(display_width, display_height);
+ set_emul_resolution(display_width, display_height);
set_emul_sdl_bpp(32);
if (blank_guide_enable == true) {
@@ -230,7 +230,7 @@ void maruskin_shm_init(uint64 swt_handle,
/* byte */
int shm_size =
- get_emul_lcd_width() * get_emul_lcd_height() * 4;
+ get_emul_resolution_width() * get_emul_resolution_height() * 4;
/* base + 1 = sdb port */
/* base + 2 = shared memory key */
diff --git a/tizen/src/skin/maruskin_operation.c b/tizen/src/skin/maruskin_operation.c
index cccba80504..a1d2e32b31 100644
--- a/tizen/src/skin/maruskin_operation.c
+++ b/tizen/src/skin/maruskin_operation.c
@@ -407,7 +407,7 @@ QemuSurfaceInfo *get_screenshot_info(void)
return NULL;
}
- int length = get_emul_lcd_width() * get_emul_lcd_height() * 4;
+ int length = get_emul_resolution_width() * get_emul_resolution_height() * 4;
INFO("screenshot data length:%d\n", length);
if (0 >= length) {
diff --git a/tizen/src/emul_state.c b/tizen/src/emul_state.c
index 147dea92c9..9f16e6bf02 100644
--- a/tizen/src/emul_state.c
+++ b/tizen/src/emul_state.c
@@ -1,5 +1,5 @@
/*
- * Emulator
+ * Emulator State Information
*
* Copyright (C) 2011 - 2013 Samsung Electronics Co., Ltd. All rights reserved.
*
@@ -56,24 +56,24 @@ int get_emul_skin_enable(void)
return _emul_info.skin_enable;
}
-/* display screen size */
-void set_emul_lcd_size(int width, int height)
+/* display screen resolution */
+void set_emul_resolution(int width, int height)
{
- _emul_info.lcd_size_w = width;
- _emul_info.lcd_size_h = height;
+ _emul_info.resolution_w = width;
+ _emul_info.resolution_h = height;
INFO("emulator graphic resolution : %dx%d\n",
- _emul_info.lcd_size_w, _emul_info.lcd_size_h);
+ _emul_info.resolution_w, _emul_info.resolution_h);
}
-int get_emul_lcd_width(void)
+int get_emul_resolution_width(void)
{
- return _emul_info.lcd_size_w;
+ return _emul_info.resolution_w;
}
-int get_emul_lcd_height(void)
+int get_emul_resolution_height(void)
{
- return _emul_info.lcd_size_h;
+ return _emul_info.resolution_h;
}
/* sdl bits per pixel */